@@ -1,12 +1,11 @@
 import os
 import sys
 
-
 __all__ = ['__author__', '__author_email__', '__version__']
 
 __author__ = "Matthew Wardrop, Dan Frank"
 __author_email__ = "matthew.wardrop@airbnb.com, dan.frank@airbnb.com"
-__version__ = "0.1.2"
+__version__ = "0.3.3"
 
 
 # These are the core dependencies, and should not include those which are used only in handling specific protocols.
@@ -18,7 +17,7 @@ __dependencies__ = [
 
     "pyyaml",  # YAML configuration parsing
     "decorator",  # Decorators used by caching routines
-    "progressbar2",  # Support for progressbars in logging routines
+    "progressbar2>=3.30.0",  # Support for progressbars in logging routines
 
     # Database querying libraries
     "jinja2",  # Templating support in databases
@@ -26,17 +25,19 @@ __dependencies__ = [
     "sqlparse",  # Neatening of SQL based queries (mainly to avoid missing the cache)
 ]
 
-if os.name == 'posix' and sys.version_info[0] < 3:
+PY2 = sys.version_info[0] == 2
+if os.name == 'posix' and PY2:
     __dependencies__.append('subprocess32')  # Python 3.2+ subprocess handling for Python 2
 
 __optional_dependencies__ = {
     # Databases
     'hiveserver2': [
+        'pyhive[Hive]' if PY2 else 'pyhive>=0.3.0[Hive]',  # Primary client
         'impyla>=0.14.0',  # Primary client
     ],
 
     'presto': [
-        'pyhive',  # Primary client
+        'pyhive[Presto]' if PY2 else 'pyhive>=0.3.0[Presto]',  # Primary client
         'sqlalchemy',  # Schema traversal
         'werkzeug',  # Schema traversal
     ],
